build_ctx

Function build_ctx 

pub fn build_ctx(
    mount: &str,
    query: &str,
    token: Option<&str>,
    csrf: Option<&str>,
) -> ReqCtx
Build a request context, verifying the auth cookie into claims if present and carrying the raw CSRF cookie through for crate::csrf to check.