pub fn guard_ui(ctx: &ReqCtx) -> Option<ApiResponse>Expand description
UI guard for the dashboard and other non-resource pages: Some(redirect)
when auth is configured and the visitor is unauthenticated or MFA-pending.
pub fn guard_ui(ctx: &ReqCtx) -> Option<ApiResponse>UI guard for the dashboard and other non-resource pages: Some(redirect)
when auth is configured and the visitor is unauthenticated or MFA-pending.