pub async fn mfa_setup_page(ctx: &ReqCtx, error: Option<&str>) -> ApiResponseExpand description
Setup page: shows a QR + secret and asks the user to confirm a code to enable MFA. Skippable — the “Skip for now” link just goes back to the dashboard.
pub async fn mfa_setup_page(ctx: &ReqCtx, error: Option<&str>) -> ApiResponseSetup page: shows a QR + secret and asks the user to confirm a code to enable MFA. Skippable — the “Skip for now” link just goes back to the dashboard.