Authorizer

Trait Authorizer 

pub trait Authorizer: Send + Sync {
    // Required method
    fn can(&self, roles: &[String], resource: &str, action: &Action<'_>) -> bool;
}
A pluggable authorization policy. can is synchronous and called several times per request, so an implementation must not perform I/O here — a DB-backed one reads a pre-loaded in-memory cache.

Required Methods

fn can(&self, roles: &[String], resource: &str, action: &Action<'_>) -> bool

Whether a principal holding roles may perform action on resource (the resource’s base_path()).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors