Skip to main contentModule crud
Source - create
- Authorize, filter to writable columns, insert, and record the create.
- delete
- Authorize, delete (soft or hard per the resource), and record the record as
it last existed.
- update
- Authorize, filter to writable columns, update, and record the diff against
the row it replaced.