pub async fn remove_record(index: &str, id: &str)Expand description
Remove a record from the index after a delete. Best-effort, same rationale as
index_record.
pub async fn remove_record(index: &str, id: &str)Remove a record from the index after a delete. Best-effort, same rationale as
index_record.