derive_headers

Function derive_headers 

pub fn derive_headers(rows: &[Value], pk: &str) -> Vec<String>
Derive table column headers from a set of rows: the primary key first, then the remaining keys of the first row in their natural order.